@@ -159,6 +159,8 @@ void ImportCertificateDialog::accept()
 					{
 						KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( "/etc/ipsec.d/certs" ) );
 						GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist and could not be created." ).arg("/etc/ipsec.d/certs" ),GlobalConfig->error );
+						GlobalConfig->appPointer->restoreOverrideCursor();
+						return;
 					}
 					else
 					{
@@ -168,6 +170,8 @@ void ImportCertificateDialog::accept()
 							{
 								KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( "/etc/ipsec.d/cacerts" ) );
 								GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist and could not  be created." ).arg( "/etc/ipsec.d/cacerts" ),GlobalConfig->error );
+								GlobalConfig->appPointer->restoreOverrideCursor();
+								return;
 							}
 							else
 							{
@@ -187,6 +191,8 @@ void ImportCertificateDialog::accept()
 			{
 				KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( certpath ) );
 				GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist." ).arg( certpath ),GlobalConfig->error );
+				GlobalConfig->appPointer->restoreOverrideCursor();
+				return;
 			}
 			else
 			{
@@ -202,6 +208,8 @@ void ImportCertificateDialog::accept()
 			{
 				KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( certpath ) );
 				GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist." ).arg( certpath ),GlobalConfig->error );
+				GlobalConfig->appPointer->restoreOverrideCursor();
+				return;
 			}
 			else
 			{
@@ -234,6 +242,7 @@ void ImportCertificateDialog::accept()
 		{
 			importOk = false;
 			KMessageBox::sorry( 0, i18n( "Private key password (again) field can not be empty!" ), i18n( "Password Empty or Too Short" ) );
+			GlobalConfig->appPointer->restoreOverrideCursor();
 			return;
 		}
 		if ( importOk )
@@ -242,6 +251,7 @@ void ImportCertificateDialog::accept()
 			{
 				importOk = false;
 				KMessageBox::sorry( 0, i18n( "Private key passwords does not match!" ), i18n( "Passwords Do Not Match" ) );
+				GlobalConfig->appPointer->restoreOverrideCursor();
 				return;
 			}
 			else
@@ -265,6 +275,8 @@ void ImportCertificateDialog::accept()
 		// program is NOT installed
 		KMessageBox::error ( this, i18n( "The required tool (%1) is not installed, please install it first and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
 		found=false;
+		GlobalConfig->appPointer->restoreOverrideCursor();
+		return;
 	}
 
 	if( !found)
@@ -272,6 +284,8 @@ void ImportCertificateDialog::accept()
 		KMessageBox::error( this, i18n( "Unable to find \"%1\"!" ).arg("openssl") );
 		GlobalConfig->appendLogEntry(i18n( "Unable to find \"%1\"!" ).arg("openssl") ,GlobalConfig->error);
 		importOk = false;
+		GlobalConfig->appPointer->restoreOverrideCursor();
+		return;
 	}
 
 
@@ -285,7 +299,6 @@ void ImportCertificateDialog::accept()
 			type="racoon";
 		else
 			type="OpenVPN";
-
 		QFile certpathtest( certpath + "/." );
 
 		if ( !certpathtest.exists() )
@@ -293,6 +306,8 @@ void ImportCertificateDialog::accept()
 			KMessageBox::error( this, i18n( "%1 certificate path (%2) does not exist!" ).arg(type).arg( certpath ) );
 			GlobalConfig->appendLogEntry(i18n( "%1 certificate path (%2) does not exist!" ).arg(type).arg( certpath ) ,GlobalConfig->error);
 			importOk=false;
+			GlobalConfig->appPointer->restoreOverrideCursor();
+			return;
 		}
 		else
 		{
@@ -302,6 +317,8 @@ void ImportCertificateDialog::accept()
 				KMessageBox::error( this, i18n( "%1 certificate path (%2) is not writeable!" ).arg(type).arg( certpath ) );
 				GlobalConfig->appendLogEntry(i18n( "%1 certificate path (%2) is not writeable!" ).arg(type).arg( certpath )  ,GlobalConfig->error);
 				importOk = false;
+				GlobalConfig->appPointer->restoreOverrideCursor();
+				return;
 			}
 			else
 			{
@@ -377,6 +394,8 @@ void ImportCertificateDialog::accept()
 		if ( !ImportProcess->start() )
 		{
 			KMessageBox::sorry( this, i18n( "Unable to start process (%1)!" ).arg("openssl") );
+			GlobalConfig->appPointer->restoreOverrideCursor();
+			return;
 		}
 		else
 		{
@@ -399,6 +418,8 @@ void ImportCertificateDialog::canAccept()
 	{
 		KMessageBox::sorry( 0, i18n( "Certificate import failed." ), i18n( "Import Failed" ) );
 		GlobalConfig->appendLogEntry ( i18n( "Certificate import: certificate could not be imported." ),GlobalConfig->error );
+		GlobalConfig->appPointer->restoreOverrideCursor();
+		return;
 	}
 
 	if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan)
@@ -416,6 +437,8 @@ void ImportCertificateDialog::canAccept()
 					{
 						// program is NOT installed
 						KMessageBox::information ( this, i18n( "The required tool (%1) is not installed, please install it before you are connecting and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
+						GlobalConfig->appPointer->restoreOverrideCursor();
+						return;
 					}
 					break;
 				}
@@ -437,6 +460,8 @@ void ImportCertificateDialog::canAccept()
 					{
 						// program is NOT installed
 						KMessageBox::information ( this, i18n( "The required tool (%1) is not installed, please install it before you are connecting and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
+						GlobalConfig->appPointer->restoreOverrideCursor();
+						return;
 					}
 					break;
 				}
@@ -458,6 +483,8 @@ void ImportCertificateDialog::canAccept()
 					{
 						// program is NOT installed
 						KMessageBox::information ( this, i18n( "The required tool (%1) is not installed, please install it before you are connecting and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
+						GlobalConfig->appPointer->restoreOverrideCursor();
+						return;
 					}
 					break;
 				}
@@ -519,6 +546,8 @@ void ImportCertificateDialog::doCacert()
 			KMessageBox::error( 0, i18n( "Unable to extract CA certificate!" ), i18n( "Extract Failed" ) );
 			GlobalConfig->appendLogEntry ( i18n( "Certificate import: CA certificate could not be extracted." ),GlobalConfig->error );
 			importSuccess=false;
+			GlobalConfig->appPointer->restoreOverrideCursor();
+			return;
 		}
 		else
 		{
@@ -560,6 +589,8 @@ void ImportCertificateDialog::doPrivateKey()
 
 			GlobalConfig->appendLogEntry ( i18n( "Certificate import: private key could not extracted." ),GlobalConfig->error );
 			importSuccess=false;
+			GlobalConfig->appPointer->restoreOverrideCursor();
+			return;
 		}
 		else
 		{
@@ -607,6 +638,8 @@ void ImportCertificateDialog::doCreateHash()
 			KMessageBox::sorry( this, i18n( "Unable to start process (%1)!" ).arg("hash") );
 			GlobalConfig->appendLogEntry ( i18n( "Certificate import: hash could not created." ),GlobalConfig->error );
 			importSuccess=false;
+			GlobalConfig->appPointer->restoreOverrideCursor();
+			return;
 		}
 		else
 		{
@@ -652,6 +685,8 @@ void ImportCertificateDialog::doLink()
 			KMessageBox::sorry( this, i18n( "Unable to start process (%1)!" ).arg("ln -s") );
 				GlobalConfig->appendLogEntry ( i18n( "Certificate import: Link could not created." ),GlobalConfig->error );
 			importSuccess=false;
+			GlobalConfig->appPointer->restoreOverrideCursor();
+			return;
 		}
 		else
 		{
