@@ -152,16 +152,22 @@ void ImportProfileDialog::canAccept()
 	if (Description.isEmpty())
 		Description = config.readEntry("!Description",i18n("Profile imported from file %1.").arg(filename));
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: description found: %1").arg(Description), GlobalConfig->debug);
+	if (!Description.isEmpty())
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: description found: %1").arg(Description), GlobalConfig->debug);
+	}
 
 	QString Gateway = config.readEntry( "Host", "" );
 
 	if (Gateway.isEmpty())
 		Gateway = config.readEntry( "!Host", "" );
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: gateway found: %1").arg(Gateway), GlobalConfig->debug);
+	if (!Gateway.isEmpty())
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: gateway found: %1").arg(Gateway), GlobalConfig->debug);
+	}
 
 	int AuthType = config.readNumEntry( "AuthType" , -1 );
 
@@ -176,33 +182,44 @@ void ImportProfileDialog::canAccept()
 	if (GroupName.isEmpty())
 		GroupName = "importedProfile";
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: group name found: %1").arg(GroupName), GlobalConfig->debug);
+	if (!GroupName.isEmpty())
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: group name found: %1").arg(GroupName), GlobalConfig->debug);
+	}
 
 	QString GroupPwd = config.readEntry( "GroupPwd" , "" );
 
-	if (GroupPwd.isEmpty())
+	if (GroupName.isEmpty())
 		GroupPwd = config.readEntry( "!GroupPwd", "" );
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: group password found: %1").arg(GroupPwd), GlobalConfig->debug);
+	if (!GroupName.isEmpty())
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: group password found: %1").arg(GroupPwd), GlobalConfig->debug);
+	}
 
 	QString enc_GroupPwd = config.readEntry( "enc_GroupPwd", "" );
 
 	if (enc_GroupPwd.isEmpty())
 		enc_GroupPwd = config.readEntry( "!enc_GroupPwd", "" );
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: encrypted group password found: %1").arg(enc_GroupPwd), GlobalConfig->debug);
+	if (!enc_GroupPwd.isEmpty())
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: encrypted group password found: %1").arg(enc_GroupPwd), GlobalConfig->debug);
+	}
 
 	QString Username = config.readEntry( "Username" , "" );
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: user name  found: %1").arg(Username), GlobalConfig->debug);
+	if (!Username.isEmpty())
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: user name  found: %1").arg(Username), GlobalConfig->debug);
+	}
 
 	bool saveUserPassword = config.readBoolEntry( "SaveUserPassword", FALSE );
 
-
 	if (saveUserPassword == false)
 		config.readBoolEntry( "!SaveUserPassword", FALSE );
 
@@ -214,27 +231,37 @@ void ImportProfileDialog::canAccept()
 
 	QString UserPassword = config.readEntry( "UserPassword", "" );
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: user password found: %1").arg(UserPassword), GlobalConfig->debug);
 
 	if (UserPassword.isEmpty())
 		UserPassword = config.readEntry( "!UserPassword", "" );
 
-	QString enc_UserPassword = config.readEntry( "enc_UserPassword", "" );
+	if (!UserPassword.isEmpty())
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: user password found: %1").arg(UserPassword), GlobalConfig->debug);
+	}
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: encrypted user password found: %1").arg(enc_UserPassword), GlobalConfig->debug);
+	QString enc_UserPassword = config.readEntry( "enc_UserPassword", "" );
 
 	if (enc_UserPassword.isEmpty())
 		enc_UserPassword = config.readEntry( "!enc_UserPassword", "" );
 
+	if (!enc_UserPassword.isEmpty())
+	{
+	if (GlobalConfig->KvpncDebugLevel > 0)
+		GlobalConfig->appendLogEntry(i18n("PCF import: encrypted user password found: %1").arg(enc_UserPassword), GlobalConfig->debug);
+	}
+
 	QString NtDomain = config.readEntry( "NTDomain" );
 
 	if (NtDomain.isEmpty())
 		NtDomain = config.readEntry( "!NTDomain", "" );
 
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: NT domain found: %1").arg(NtDomain), GlobalConfig->debug);
+	if (!NtDomain.isEmpty())
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: NT domain found: %1").arg(NtDomain), GlobalConfig->debug);
+	}
 
 	//	bool enableBackup = config.readBoolEntry( "EnableBackup" , FALSE );
 	QString BackupServer = config.readEntry( "BackupServer", "" );
@@ -254,7 +281,7 @@ void ImportProfileDialog::canAccept()
 		GlobalConfig->appendLogEntry(i18n("PCF import: Diffie Hellman group found: %1").arg(QString().setNum(DHGroup)), GlobalConfig->debug);
 
 	//	bool ForceKeepAlives = config.readBoolEntry( "ForceKeepAlives", FALSE );
-	//	int PeerTimeout = config.readNumEntry( "PeerTimeout", -1 );
+
 	//	bool EnableLocalLAN = config.readBoolEntry( "EnableLocalLAN", FALSE ); // nur auslesen aber immer aus :)
 	//	bool EnableSplitDNS = config.readBoolEntry( "EnableSplitDNS", FALSE );
 
@@ -289,18 +316,17 @@ void ImportProfileDialog::canAccept()
 		useIkeGroup = true;
 	}
 
-	int PeerTimeout=600000; // value
+	int PeerTimeout = config.readNumEntry( "PeerTimeout", -1 );
 
-	if ( config.readNumEntry ("PeerTimeout",0) > 2)
-		PeerTimeout= (config.readNumEntry ("PeerTimeout",0)-1)*60; // read minutes but store seconds
-
-	if (GlobalConfig->KvpncDebugLevel > 0)
-		GlobalConfig->appendLogEntry(i18n("PCF import: peer timeout found: %1").arg(QString().setNum(PeerTimeout)), GlobalConfig->debug);
+	if (PeerTimeout > -1 )
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0)
+			GlobalConfig->appendLogEntry(i18n("PCF import: peer timeout found: %1").arg(QString().setNum(PeerTimeout)), GlobalConfig->debug);
+	}
 
 	QString PerfectForwardSecrecy = ""; //QString("dh"+QString().setNum(DHGroup));
 	//	bool usePerfectForwardSecrety = false;
 
-	//GroupPwd = downloadDecPasswd( enc_GroupPwd );
 	CiscoPasswdDecoder dec (filename);
 	QString userpasswd="";
 	QString grouppasswd="";
@@ -359,12 +385,21 @@ void ImportProfileDialog::canAccept()
 	acc->setUseUdp( useUdp );
 // 	acc->setUdpPort( 10000 );
 
+	// FIXME what is psk and what is cert?
+	acc->setAuthType( VpnAccountData::psk);
+
+
+
 	if (useLocalPort){
 		acc->setLocalPort(TunnelingPort);
 		acc->setUseLocalPort(true);
 	}
 
-
+	if (PeerTimeout > -1 )
+	{
+		// read minutes but store seconds
+		acc->setPeerTimeout( PeerTimeout*60 );
+	}
 
 	/*
 	std::cout << Description
