@@ -181,6 +181,8 @@ private:
 	bool pppdHasMppeSupport; //< true if pppd has mppe support
 	bool testOldPppdStyle;
 	bool shutdownIsCalled;
+	bool testPppdReplacedefaultroute;
+	bool pppdHasReplacedefaultrouteSupport;
 
 	QString OldDefaultroute;
 	QString VpncConnectScript;
@@ -228,6 +230,7 @@ private:
 	QProcess *PptpRouteProcess;
 	QProcess *ChmodProcess;
 	QProcess *pppdUpProcess;
+	QProcess *pppdDelDefaultRouteProcess;
 
 	int TimeOutProcess; //< for timeout
 	int ConnectingProcess; //< for killing process
@@ -318,6 +321,7 @@ private slots:
 	void quitCalled();
 	void quitCalledKicker();
 	void advancedSettingsClicked();
+	void pptpProcessExited();
 	
 	void importProfileClicked(); //< PCF import
 
