@@ -37,6 +37,7 @@ KVpncConfig::KVpncConfig(QWidget *parent)
 	pathToFreeswan = "";
 	pathToPppd="";
 	pathToPptp="";
+	pathToL2tpd="";
 	pathToKill="";
 	pathToKillall="";
 	pathToPing="";
@@ -58,6 +59,7 @@ KVpncConfig::KVpncConfig(QWidget *parent)
 	TmpGatewayIP="";
 	TmpXauthInterPasscode="";
 	TmpPrivateKeyPass="";
+	TmpHttpProxyPassword="";
 
 	connectSleepDelay = 15;
 	connectSleepRetry = 0;
@@ -101,8 +103,6 @@ KVpncConfig::KVpncConfig(QWidget *parent)
 
 	ToolList = new QPtrList<ToolInfo>();
 	ToolList->setAutoDelete( TRUE );
-	ToolList = Utils(this).getToolList();
-	getToolsInfo();
 
 	AccountList = new QPtrList<VpnAccountData>();
 	AccountList->setAutoDelete( TRUE ); // the list owns the objects
@@ -281,6 +281,7 @@ void KVpncConfig::saveOptions()
 	config->writeEntry( "Path to freeswan", pathToFreeswan );
 	config->writeEntry( "Path to pppd", pathToPppd );
 	config->writeEntry( "Path to pptp", pathToPptp );
+	config->writeEntry( "Path to l2tpd", pathToL2tpd );
 	config->writeEntry( "Path to kill", pathToKill );
 	config->writeEntry( "Path to kill-all", pathToKillall );
 	config->writeEntry( "Path to ping", pathToPing );
@@ -562,7 +563,9 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "Set default route", it->getSetDefaultRoute() );
 				config->writeEntry( "Replace default route", it->getReplaceDefaultRoute() );
 				config->writeEntry( "Use own MTU", it->getUseMtu() );
+				config->writeEntry( "Use own MRU", it->getUseMru() );
 				config->writeEntry( "MTU for pppd", it->getMtu() );
+				config->writeEntry( "MRU for pppd", it->getMru() );
 				config->writeEntry( "Use Virtual IP", it->getUseVirtualIP() );
 				config->writeEntry( "Virtual IP", it->getVirtualIP() );
 				config->writeEntry( "PSK is in file", it->getPskIsInFile() );
@@ -584,6 +587,7 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "Use userdefinied cipher", it->getUseUserdefiniedCipher() );
 				config->writeEntry( "Userdefinied cipher", it->getUserdefiniedCipher() );
 				config->writeEntry( "Use redirect gateway", it->getUseRedirectGateway() );
+				appPointer->processEvents();
 				config->writeEntry( "Use TLS auth", it->getUseTlsAuth() );
 				config->writeEntry( "TLS auth file", it->getTlsAuthFile() );
 				config->writeEntry( "Use HTTP proxy", it->getUseHttpProxy() );
@@ -608,6 +612,11 @@ void KVpncConfig::saveOptions()
 				config->writeEntry("Disable CCP", it->getDisableCcp() );
 				config->writeEntry("Use smartcard", it->getUseSmardcard() );
 				config->writeEntry("Use Xauth interactive", it->getUseXauthInteractive() );
+				config->writeEntry("Use HTTP Proxy Authentication", it->getUseHttpProxyAuth() );
+				config->writeEntry("Use HTTP Proxy Authtype", it->getHttpProxyAuthType() );
+				config->writeEntry("Use HTTP Proxy Auth user", it->getHttpProxyUser() );
+				config->writeEntry("Use HTTP Proxy Auth pass", it->getHttpProxyPass() );
+				config->writeEntry("Use only CA cert and user auth", it->getUseOnlyCaCertAndUserAuth() );
 
 				appPointer->processEvents();
 
@@ -670,6 +679,7 @@ void KVpncConfig::loadOptions()
 	pathToNetstat = config->readEntry( "Path to netstat", "/bin/netstat" );
 	pathToPppd = config->readEntry ("Path to pppd","/usr/sbin/pppd");
 	pathToPptp = config->readEntry ("Path to pptp","/usr/sbin/pptp");
+	pathToL2tpd = config->readEntry ("Path to l2tpd","/usr/sbin/l2tpd");
 	pathToKill = config->readEntry ("Path to kill","/bin/kill");
 	pathToKillall = config->readEntry ("Path to kill-all","/usr/bin/killall");
 	pathToPing = config->readEntry ("Path to ping","/bin/ping");
@@ -940,7 +950,9 @@ void KVpncConfig::loadOptions()
 			data->setSetDefaultRoute( config->readBoolEntry( "Set default route", true ));
 			data->setReplaceDefaultRoute( config->readBoolEntry( "Replace default route", false ));
 			data->setUseMtu( config->readBoolEntry( "Use own MTU", false ));
+			data->setUseMru( config->readBoolEntry( "Use own MRU", false ));
 			data->setMtu( config->readNumEntry( "MTU for pppd", 1492 ));
+			data->setMru( config->readNumEntry( "MRU for pppd", 1492 ));
 			data->setUseVirtualIP( config->readBoolEntry( "Use Virtual IP", false ));
 			data->setVirtualIP( config->readEntry( "Virtual IP", "" ));
 			data->setPskIsInFile( config->readBoolEntry( "PSK is in file", false ));
@@ -997,6 +1009,11 @@ void KVpncConfig::loadOptions()
 			data->setDisableCcp( config->readBoolEntry("Disable CCP",false) );
 			data->setUseSmardcard( config->readBoolEntry("Use smartcard", false) );
 			data->setUseXauthInteractive(config->readBoolEntry("Use Xauth interactive", false) );
+			data->setUseHttpProxyAuth( config->readBoolEntry("Use HTTP Proxy Authentication", false ) );
+			data->setHttpProxyAuthType( config->readEntry("Use HTTP Proxy Authtype", "basic") );
+			data->setHttpProxyUser( config->readEntry("Use HTTP Proxy Auth user", "") );
+			data->setHttpProxyPass( config->readEntry("Use HTTP Proxy Auth pass", "") );
+			data->setUseOnlyCaCertAndUserAuth(config->readBoolEntry("Use only CA cert and user auth", false) );
 
 			appPointer->processEvents();
 			AccountList->append( data );
@@ -1157,7 +1174,7 @@ void KVpncConfig::getToolsInfo()
 			}
 			else
 			{
-				std::cout << "Invalid tool!" << std::endl;
+// 				std::cout << "Invalid tool!" << std::endl;
 			}
 			appPointer->processEvents();
 		}
@@ -1366,7 +1383,9 @@ void KVpncConfig::removeEntry(QString Name)
 					config->deleteEntry( "Set default route" );
 					config->deleteEntry( "Replace default route" );
 					config->deleteEntry( "Use own MTU" );
+					config->deleteEntry( "Use own MRU" );
 					config->deleteEntry( "MTU for pppd" );
+					config->deleteEntry( "MRU for pppd" );
 					config->deleteEntry( "Use Virtual IP" );
 					config->deleteEntry( "Virtual IP" );
 					config->deleteEntry( "PSK is in file" );
