@@ -61,6 +61,7 @@ public:
 	QString pathToFreeswan;
 	QString pathToPppd;
 	QString pathToPptp;
+	QString pathToL2tpd;
 	QString pathToKill;
 	QString pathToKillall;
 	QString pathToPing;
@@ -83,6 +84,7 @@ public:
 	QString TmpGatewayIP;
 	QString TmpXauthInterPasscode; //< from Xauth interactive passcode dialog
 	QString TmpPrivateKeyPass;
+	QString TmpHttpProxyPassword;
 
 	bool minimizeAfterConnect;
 	bool showDebugConsole;
