@@ -69,6 +69,7 @@ NewProfileWizard::NewProfileWizard(KVpncConfig* GlobalConfig)
 	PerfectForwardSecrecy = "";
 	IkeGroup = "";
 	Description ="";
+	Name ="None";
 	useApplicationVersion = false;
 	useGlobalIpsecSecret = false;
 	useIkeGroup = false;
@@ -142,14 +143,6 @@ void NewProfileWizard::accept()
 			else
 				newProfileCreated=false;
 		}
-		else	if ( profileData->getConnectionType() == VpnAccountData::openvpn )
-		{
-			
-			if (importProfile(VpnAccountData::openvpn) == true)
-				newProfileCreated=true;
-			else
-				newProfileCreated=false;
-		}
 	}
 	else
 	{
@@ -241,6 +234,15 @@ void NewProfileWizard::setupPages()
 	newprofilewizardopenvpnselectionpagecontent = new NewProfileWizardOpenvpnSelection(newprofilewizardopenvpnselectionpage);
 	newprofilewizardopenvpnselectionpage->sizeHint();
 
+	newprofilewizardopenvpnauthpage = new QHBox( 0 );
+	// 	newprofilewizardopenvpnauthpage->setSpacing(8);
+	QLabel *setupPixmapContent71 = new QLabel( newprofilewizardopenvpnauthpage);
+	setupPixmapContent71->setPixmap(*SetupPixmap);
+	setupPixmapContent71->resize(setupPixmapContent71->sizeHint());
+	newprofilewizardopenvpnauthpagecontent = new NewProfileWizardOpenvpnAuth(newprofilewizardopenvpnauthpage);
+	newprofilewizardopenvpnauthpage->sizeHint();
+	connect (newprofilewizardopenvpnauthpagecontent->AuthWithUsernameAndPasswordCheckBox, SIGNAL(toggled(bool)), this, SLOT(authenticateWithUsernameAndPasswordToggled(bool)));
+
 	newprofilewizardopenvpnpage = new QHBox( 0 );
 	// 	newprofilewizardopenvpnpage->setSpacing(8);
 	QLabel *setupPixmapContent8 = new QLabel( newprofilewizardopenvpnpage);
@@ -294,20 +296,13 @@ void NewProfileWizard::setupPages()
 	newprofilewizardpptppagecontent->UseNoMPPECompressionCheckbox->setChecked( profileData->getDisableMPPEComp());
 	newprofilewizardpptppagecontent->UseNoDeflateCheckbox->setChecked(profileData->getUseNoDeflate());
 
-	// general settings
-	newprofilewizardgeneralpage = new QHBox( 0 );
-	// 	newprofilewizardgeneralpage->setSpacing(8);
-	QLabel *setupPixmapContent10 = new QLabel( newprofilewizardgeneralpage);
-	setupPixmapContent10->setPixmap(*SetupPixmap);
-	setupPixmapContent10->resize(setupPixmapContent10->sizeHint());
-	newprofilewizardgeneralpagecontent = new NewProfileWizardGeneral(newprofilewizardgeneralpage);
-	newprofilewizardgeneralpage->sizeHint();
+	newprofilewizardpptppagecontent->PptpDefaultRouteComboBox->setCurrentItem(1);
 
 	newprofilewizardauthselectionpage = new QHBox( 0 );
 	// 	newprofilewizardauthselectionpage->setSpacing(8);
-	QLabel *setupPixmapContent71 = new QLabel( newprofilewizardauthselectionpage);
-	setupPixmapContent71->setPixmap(*SetupPixmap);
-	setupPixmapContent71->resize(setupPixmapContent71->sizeHint());
+	QLabel *setupPixmapContent81 = new QLabel( newprofilewizardauthselectionpage);
+	setupPixmapContent81->setPixmap(*SetupPixmap);
+	setupPixmapContent81->resize(setupPixmapContent81->sizeHint());
 	newprofilewizardauthselectioncontent = new NewProfileWizardAuthSelection(newprofilewizardauthselectionpage);
 	newprofilewizardauthselectionpage->sizeHint();
 
@@ -321,6 +316,7 @@ void NewProfileWizard::setupPages()
 	newprofilewizardpskpage->sizeHint();
 
 	connect ( newprofilewizardpskcontent->PskInFileCheckBox , SIGNAL(toggled (bool)), this, SLOT(pskIsInFileToggled(bool)));
+	connect ( newprofilewizardpskcontent->PSKLineEdit , SIGNAL(textChanged ( const QString & )), this, SLOT(pskInputToggled(const QString&)));
 
 	newprofilewizardp12certselectionpage = new QHBox( 0 );
 	// 	newprofilewizardp12certselectionpage->setSpacing(8);
@@ -348,6 +344,10 @@ void NewProfileWizard::setupPages()
 	newprofilewizarduserpagecontent = new NewProfileWizardUser(newprofilewizarduserpage);
 	newprofilewizarduserpage->sizeHint();
 
+	connect ( newprofilewizarduserpagecontent->PasswordEdit , SIGNAL( textChanged(const QString&)), this, SLOT(userpassToggled(const QString& )));
+	connect ( newprofilewizarduserpagecontent->UsernameLineEdit , SIGNAL( textChanged(const QString&)), this, SLOT(usernameToggled(const QString& )));
+
+
 	// network
 	newprofilewizardnetworkpage = new QHBox( 0 );
 	// 	newprofilewizardnetworkpage->setSpacing(8);
@@ -377,15 +377,6 @@ void NewProfileWizard::setupPages()
 	connect( newprofilewizardnatcontent->UseUdpCheckbox, SIGNAL( toggled(bool) ), this, SLOT( useUdpToggled(bool) ) );
 	connect( newprofilewizardnatcontent->UdpPortCheckbox, SIGNAL( toggled(bool) ), this, SLOT( udpPortToggled(bool) ) );
 
-	// general
-	newprofilewizardgeneralpage = new QHBox( 0 );
-	// 	newprofilewizardgeneralpage->setSpacing(8);
-	QLabel *setupPixmapContent78 = new QLabel( newprofilewizardgeneralpage);
-	setupPixmapContent78->setPixmap(*SetupPixmap);
-	setupPixmapContent78->resize(setupPixmapContent78->sizeHint());
-	newprofilewizardgeneralpagecontent = new NewProfileWizardGeneral(newprofilewizardgeneralpage);
-	newprofilewizardgeneralpage->sizeHint();
-	insertPage(newprofilewizardgeneralpage,"<b>"+i18n("General settings")+"</b>", -1);
 
 	// connectionstatuscheck
 	newprofilewizardconnectionstatuscheckpage = new QHBox( 0 );
@@ -411,6 +402,15 @@ void NewProfileWizard::setupPages()
 	newprofilewizardconnectoptionscontent->AutoConnectProfileComboBox->hide(); //TODO_ later
 	insertPage(newprofilewizardconnectoptionspage,"<b>"+i18n("Connect options")+"</b>", -1);
 
+	// general
+	newprofilewizardgeneralpage = new QHBox( 0 );
+	// 	newprofilewizardgeneralpage->setSpacing(8);
+	QLabel *setupPixmapContent78 = new QLabel( newprofilewizardgeneralpage);
+	setupPixmapContent78->setPixmap(*SetupPixmap);
+	setupPixmapContent78->resize(setupPixmapContent78->sizeHint());
+	newprofilewizardgeneralpagecontent = new NewProfileWizardGeneral(newprofilewizardgeneralpage);
+	newprofilewizardgeneralpage->sizeHint();
+	insertPage(newprofilewizardgeneralpage,"<b>"+i18n("General settings")+"</b>", -1);
 
 	// setup end page
 	endpage = new QHBox( 0 );
@@ -478,9 +478,9 @@ void NewProfileWizard::next ()
 						//account->setName( QString( account->getName() + "_2" ) );
 						// 				KMessageBox::information ( this, i18n( "Profile name exists!\n It will be renamed to \"%1\"." ).arg( account->getName() ), i18n( "Name exist, renamed" ) );
 						KMessageBox::error ( this, i18n( "Profile name exists!"), i18n( "Name Exists" ) );
-						
+
 						QString newName = KInputDialog::getText   (   i18n("New Name"),i18n("New name for profile:"),QString(Name+="_2"),&ok);
-						
+
 						if (!Name.isEmpty())
 						{
 							nameOk=true;
@@ -495,16 +495,16 @@ void NewProfileWizard::next ()
 			if ( nameOk )
 			{
 				profileData->setName(Name);
+
+				if ( GlobalConfig->KvpncDebugLevel > 0 )
+					GlobalConfig->appendLogEntry(i18n("Profile name: %1").arg(profileData->getName()), KVpncConfig::debug);
+
 				newProfileCreated = TRUE;
 			}
 			else
 			{
 				return;
 			}
-
-
-			if ( GlobalConfig->KvpncDebugLevel > 0 )
-				GlobalConfig->appendLogEntry(i18n("Name: %1").arg(newprofilewizardgeneralpagecontent->NameLineEdit->text()), KVpncConfig::debug);
 		}
 
 		if (newprofilewizardgeneralpagecontent->gatewayLineEdit->text().isEmpty())
@@ -607,6 +607,10 @@ void NewProfileWizard::next ()
 			newprofilewizardnetworkcontent->RemoteNetMaskComboBox->hide();
 			newprofilewizardnetworkcontent->RemoteNetAddrLineEdit->hide();
 			newprofilewizardnetworkcontent->RemoteNetDividetextLabel->hide();
+			insertPage(newprofilewizardopenvpnauthpage,"<b>"+i18n("OpenVPN authentication settings")+"</b>", indexOf(currentpage)+1);
+
+			connect(newprofilewizardopenvpnauthpagecontent->AuthWithUsernameAndPasswordCheckBox, SIGNAL(toggled(bool)),this,SLOT(authenticateWithUsernameAndPasswordToggled(bool)) );
+
 			insertPage ( newprofilewizardopenvpnselectionpage,"<b>"+ i18n("OpenVPN selection")+"</b>", indexOf(currentpage)+1);
 
 			if ( GlobalConfig->KvpncDebugLevel > 0 )
@@ -615,6 +619,10 @@ void NewProfileWizard::next ()
 		else if (newprofilewizardtypeselectionpagecontent->PptpRadioButton->isChecked())
 		{
 			profileData->setConnectionType( VpnAccountData::pptp );
+			profileData->setUseMtu(true);
+			profileData->setUseMru(true);
+			profileData->setMtu( 1000 );
+			profileData->setMru( 1000 );
 			removePage( newprofilewizardciscoselectionpage);
 			removePage( newprofilewizardciscomanuallypage);
 			removePage( newprofilewizardcertpage );
@@ -696,8 +704,8 @@ void NewProfileWizard::next ()
 					if ( realversion.find("1.",0,-1) > -1)
 					{
 						KMessageBox::information ( this, i18n("The required version (%1) of FreeSWAN/OpenSWAN was not found. You will not be able to use the Agressive Mode. It will be used the Main Mode.").arg("2"));
-					if (GlobalConfig->KvpncDebugLevel > 0)
-						GlobalConfig->appendLogEntry(i18n("The required version (%1) of FreeSWAN/OpenSWAN was not found. You will not be able to use the Agressive Mode. It will be used the Main Mode.").arg("2").arg(bin),KVpncConfig::error);
+						if (GlobalConfig->KvpncDebugLevel > 0)
+							GlobalConfig->appendLogEntry(i18n("The required version (%1) of FreeSWAN/OpenSWAN was not found. You will not be able to use the Agressive Mode. It will be used the Main Mode.").arg("2").arg(bin),KVpncConfig::error);
 					}
 				}
 			}
@@ -810,24 +818,24 @@ void NewProfileWizard::next ()
 
 		if (newprofilewizardtypeselectionpagecontent->FreeswanRadioButton->isChecked())
 		{
-				profileData->setLeftNextHop(newprofilewizardracoonpagecontent->LeftNextHopLineEdit->text() ); //TODO check valid IP
-				profileData->setRightNextHop( newprofilewizardracoonpagecontent->RightNextHopLineEdit->text( ) );//TODO check valid IP
-				profileData->setDisableOpportunisticEncryption( newprofilewizardracoonpagecontent->DisableOpportunisticEncryptionCheckBox->isChecked( ) );
-				if (newprofilewizardracoonpagecontent->DisablePfsCheckBox->isChecked())
-					profileData->setPerfectForwardSecrety("false");
-				else
-					profileData->setPerfectForwardSecrety("true");
+			profileData->setLeftNextHop(newprofilewizardracoonpagecontent->LeftNextHopLineEdit->text() ); //TODO check valid IP
+			profileData->setRightNextHop( newprofilewizardracoonpagecontent->RightNextHopLineEdit->text( ) );//TODO check valid IP
+			profileData->setDisableOpportunisticEncryption( newprofilewizardracoonpagecontent->DisableOpportunisticEncryptionCheckBox->isChecked( ) );
+			if (newprofilewizardracoonpagecontent->DisablePfsCheckBox->isChecked())
+				profileData->setPerfectForwardSecrety("false");
+			else
+				profileData->setPerfectForwardSecrety("true");
 
-				if ( GlobalConfig->KvpncDebugLevel > 0 )
-				{
-					if (newprofilewizardracoonpagecontent->DisableOpportunisticEncryptionCheckBox->isChecked())
-						GlobalConfig->appendLogEntry(i18n("Disable opportunistic encryption: %1").arg("yes").arg(newprofilewizardracoonpagecontent->HashAlgoComboBox->currentText()), KVpncConfig::debug);
-					else
-						GlobalConfig->appendLogEntry(i18n("Disable opportunistic encryption: %1").arg("no").arg(newprofilewizardracoonpagecontent->HashAlgoComboBox->currentText()), KVpncConfig::debug);
-					GlobalConfig->appendLogEntry(i18n("Right next hop: %1").arg(newprofilewizardracoonpagecontent->RightNextHopLineEdit->text()), KVpncConfig::debug);
-					GlobalConfig->appendLogEntry(i18n("Left next hop: %1").arg(newprofilewizardracoonpagecontent->LeftNextHopLineEdit->text()), KVpncConfig::debug);
-					GlobalConfig->appendLogEntry(i18n("Disable PFS: %1").arg(profileData->getPerfectForwardSecrety()), KVpncConfig::debug);
-				}
+			if ( GlobalConfig->KvpncDebugLevel > 0 )
+			{
+				if (newprofilewizardracoonpagecontent->DisableOpportunisticEncryptionCheckBox->isChecked())
+					GlobalConfig->appendLogEntry(i18n("Disable opportunistic encryption: %1").arg("yes").arg(newprofilewizardracoonpagecontent->HashAlgoComboBox->currentText()), KVpncConfig::debug);
+				else
+					GlobalConfig->appendLogEntry(i18n("Disable opportunistic encryption: %1").arg("no").arg(newprofilewizardracoonpagecontent->HashAlgoComboBox->currentText()), KVpncConfig::debug);
+				GlobalConfig->appendLogEntry(i18n("Right next hop: %1").arg(newprofilewizardracoonpagecontent->RightNextHopLineEdit->text()), KVpncConfig::debug);
+				GlobalConfig->appendLogEntry(i18n("Left next hop: %1").arg(newprofilewizardracoonpagecontent->LeftNextHopLineEdit->text()), KVpncConfig::debug);
+				GlobalConfig->appendLogEntry(i18n("Disable PFS: %1").arg(profileData->getPerfectForwardSecrety()), KVpncConfig::debug);
+			}
 		}
 
 		profileData->setExchangeMode( newprofilewizardracoonpagecontent->ExchangeModeComboBox->currentText());
@@ -854,17 +862,8 @@ void NewProfileWizard::next ()
 		profileData->setUseRedirectGateway( newprofilewizardopenvpnpagecontent->UseRedirectGatewayCheckBox->isChecked() );
 
 		insertPage( newprofilewizardauthselectionpage,"<b>"+ i18n("Authentication settings")+"</b>", indexOf(currentpage)+1);
-		if ( newprofilewizardopenvpnpagecontent->AuthWithUsernameAndPasswordCheckBox->isChecked())
-		{
-			insertPage(newprofilewizarduserpage,"<b>"+i18n("User settings")+"</b>", indexOf(currentpage)+2);
-			insertPage(newprofilewizardnetworkpage,"<b>"+ i18n("Network settings")+"</b>", indexOf(currentpage)+3);
-			insertPage(newprofilewizardnatpage,"<b>"+i18n("NAT settings")+"</b>", indexOf(currentpage)+4 );
-		}
-		else
-		{
-			insertPage(newprofilewizardnetworkpage,"<b>"+ i18n("Network settings")+"</b>", indexOf(currentpage)+2);
-			insertPage(newprofilewizardnatpage,"<b>"+i18n("NAT settings")+"</b>", indexOf(currentpage)+3 );
-		}
+		insertPage(newprofilewizardnetworkpage,"<b>"+ i18n("Network settings")+"</b>", indexOf(currentpage)+2);
+		insertPage(newprofilewizardnatpage,"<b>"+i18n("NAT settings")+"</b>", indexOf(currentpage)+3 );
 
 		profileData->setUserdefiniedCipher(newprofilewizardopenvpnpagecontent->UserdefiniedCipherComboBox->currentText());
 		profileData->setUseUserdefiniedCipher(newprofilewizardopenvpnpagecontent->UseUserdefiniedCipherCheckBox->isChecked());
@@ -900,7 +899,6 @@ void NewProfileWizard::next ()
 			}
 		}
 
-		profileData->setAuthWithUsernameAndPassword( newprofilewizardopenvpnpagecontent->AuthWithUsernameAndPasswordCheckBox->isChecked());
 		profileData->setDisableLzoCompression( newprofilewizardopenvpnpagecontent->DisableLzoCompressionCheckBox->isChecked());
 
 		if ( newprofilewizardopenvpnpagecontent->UseHttpProxyCheckBox->isChecked() )
@@ -960,14 +958,30 @@ void NewProfileWizard::next ()
 
 			else if (profileData->getConnectionType() == VpnAccountData::openvpn)
 			{
-				newprofilewizardcertcontent->x509certURLRequester->setEnabled( true );
 				newprofilewizardcertcontent->CaCertpathURLRequester->setEnabled( true );
-				newprofilewizardcertcontent->LabelCertificate->setEnabled( true );
 				newprofilewizardcertcontent->certpathURLRequester->setEnabled( true );
 				newprofilewizardcertcontent->LabelCertificatePath->setEnabled( true );
-				newprofilewizardcertcontent->privkeypathURLRequester->setEnabled( true );
-				newprofilewizardcertcontent->LabelPrivateKeyPath->setEnabled( true );
-				newprofilewizardcertcontent->LabelPrivateKeyPath->setEnabled( true );
+
+
+				if (profileData->getUseOnlyCaCertAndUserAuth())
+				{
+					newprofilewizardcertcontent->x509certURLRequester->setEnabled(false);
+					newprofilewizardcertcontent->privkeypathURLRequester->setEnabled(false);
+					newprofilewizardcertcontent->PrivkeyPasswordEdit->setEnabled(false);
+					newprofilewizardcertcontent->LabelPrivateKeyPath->setEnabled( false );
+					newprofilewizardcertcontent->LabelCertificate->setEnabled( false );
+					newprofilewizardcertcontent->LabelPrivateKeyPassword->setEnabled( false );
+
+				}
+				else
+				{
+					newprofilewizardcertcontent->x509certURLRequester->setEnabled( true );
+					newprofilewizardcertcontent->privkeypathURLRequester->setEnabled( true );
+					newprofilewizardcertcontent->PrivkeyPasswordEdit->setEnabled(true);
+					newprofilewizardcertcontent->LabelPrivateKeyPath->setEnabled( true );
+					newprofilewizardcertcontent->LabelCertificate->setEnabled( true );
+					newprofilewizardcertcontent->LabelPrivateKeyPassword->setEnabled( true );
+				}
 			}
 			if ( GlobalConfig->KvpncDebugLevel > 0 )
 				GlobalConfig->appendLogEntry(i18n("Auth selection: use certificate"), KVpncConfig::debug);
@@ -1005,9 +1019,24 @@ void NewProfileWizard::next ()
 		{
 			enterdatamanually=false;
 			removePage( newprofilewizardopenvpnpage );
-			removePage ( newprofilewizardgeneralpage );
+			removePage( newprofilewizardopenvpnauthpage);
 			if ( GlobalConfig->KvpncDebugLevel > 0 )
 				GlobalConfig->appendLogEntry(i18n("OpenVPN selection: import profile file"), KVpncConfig::debug);
+
+// 			removePage ( newprofilewizardgeneralpage );
+
+			if (importProfile(VpnAccountData::openvpn) == true)
+			{
+				newProfileCreated=true;
+				newprofilewizardgeneralpagecontent->NameLineEdit->setText( profileData->getName() );
+				newprofilewizardgeneralpagecontent->gatewayLineEdit->setText( profileData->getGateway());
+				newprofilewizardgeneralpagecontent->DescriptionLineEdit->setText( profileData->getDescription());
+			}
+			else
+			{
+				newProfileCreated=false;
+				ok = false;
+			}
 		}
 		else
 		{
@@ -1016,10 +1045,50 @@ void NewProfileWizard::next ()
 			if ( GlobalConfig->KvpncDebugLevel > 0 )
 				GlobalConfig->appendLogEntry(i18n("OpenVPN selection: enter data manually"), KVpncConfig::debug);
 		}
+
+	}
+	else if ( currentpage == newprofilewizardopenvpnauthpage )
+	{
+		if (newprofilewizardopenvpnauthpagecontent->AuthWithUsernameAndPasswordCheckBox->isChecked())
+		{
+			if ( GlobalConfig->KvpncDebugLevel > 0 )
+				GlobalConfig->appendLogEntry(i18n("OpenVPN auth: authenticate with username and password"), KVpncConfig::debug);
+			insertPage(newprofilewizarduserpage,"<b>"+i18n("User settings")+"</b>", indexOf(currentpage)+1);
+
+			profileData->setAuthWithUsernameAndPassword(true);
+
+			if (newprofilewizardopenvpnauthpagecontent->UseOnlyCaCertAndUserAuthCheckBox->isChecked())
+			{
+				profileData->setUseOnlyCaCertAndUserAuth(true);
+
+				if ( GlobalConfig->KvpncDebugLevel > 0 )
+					GlobalConfig->appendLogEntry(i18n("OpenVPN auth: use only CA cert authenticate with username and password"), KVpncConfig::debug);
+			}
+			else
+			{
+				profileData->setUseOnlyCaCertAndUserAuth(false);
+
+			}
+		}
+		else
+		{
+			if ( GlobalConfig->KvpncDebugLevel > 0 )
+				GlobalConfig->appendLogEntry(i18n("OpenVPN auth: dont authenticate with username and password"), KVpncConfig::debug);
+
+			profileData->setAuthWithUsernameAndPassword(false);
+			profileData->setUseOnlyCaCertAndUserAuth(false);
+		}
 	}
 	else if ( currentpage == newprofilewizardpptppage )
 	{
 
+		msg=i18n("These fields must be filled in:\n");
+		if (newprofilewizardpptppagecontent->NtDomainNameCheckbox->isChecked() && newprofilewizardpptppagecontent->NtDomainNameLineedit->text().isEmpty())
+		{
+			ok=false;
+			msg+="- "+i18n("NT Domain name")+"\n";
+		}
+
 		profileData->setRefuseEap(newprofilewizardpptppagecontent->RefuseEapCheckbox->isChecked() );
 		profileData->setRequireMppe(newprofilewizardpptppagecontent->RequireMppeCheckbox->isChecked()  );
 		profileData->setRefuse128BitEncryption(newprofilewizardpptppagecontent->Refuse128BitEncryptionCheckbox->isChecked() );
@@ -1030,14 +1099,31 @@ void NewProfileWizard::next ()
 		profileData->setDnsServer(newprofilewizardpptppagecontent->DnsServerLineedit->text() );
 		profileData->setUseNoBsdComp(newprofilewizardpptppagecontent->UseNoBsdCompCheckbox->isChecked());
 		profileData->setUseNoDeflate(newprofilewizardpptppagecontent->UseNoDeflateCheckbox->isChecked());
-		profileData->setSetDefaultRoute(newprofilewizardpptppagecontent->SetDefaultRouteCheckbox->isChecked());
-		profileData->setReplaceDefaultRoute(newprofilewizardpptppagecontent->ReplaceDefaultRouteCheckbox->isChecked());
+		profileData->setUseNtDomainName( newprofilewizardpptppagecontent->NtDomainNameCheckbox->isChecked());
+		profileData->setNtDomainName (newprofilewizardpptppagecontent->NtDomainNameLineedit->text());
+
+		// 		if (newprofilewizardpptppagecontent->PptpDefaultRouteComboBox->currentText() == i18n("Keep default route"))
+		if (newprofilewizardpptppagecontent->PptpDefaultRouteComboBox->currentItem() == 0)
+		{
+			profileData->setSetDefaultRoute(false);
+			profileData->setReplaceDefaultRoute(false);
+			profileData->setKeepDefaultRoute( true );
+		}
+
+		// 		if (newprofilewizardpptppagecontent->PptpDefaultRouteComboBox->currentText() == i18n("Replace default route"))
+		if (newprofilewizardpptppagecontent->PptpDefaultRouteComboBox->currentItem() == 1)
+		{
+			profileData->setSetDefaultRoute(true);
+			profileData->setReplaceDefaultRoute(true);
+			profileData->setKeepDefaultRoute( false );
+		}
+
 		profileData->setUseMtu(newprofilewizardpptppagecontent->MtuCheckbox->isChecked());
 		profileData->setMtu(newprofilewizardpptppagecontent->MtuSpinbox->value());
 		profileData->setAllowStatefulMode(newprofilewizardpptppagecontent->AllowStatefulModeCheckbox->isChecked());
 		profileData->setUseNoIpDefault(newprofilewizardpptppagecontent->UseNoIpDefaultCheckbox->isChecked());
 		profileData->setDisableMPPEComp(newprofilewizardpptppagecontent->UseNoMPPECompressionCheckbox->isChecked());
-		profileData->setKeepDefaultRoute( newprofilewizardpptppagecontent->KeepDefaultRouteCheckBox->isChecked());
+
 
 		newprofilewizardnetworkcontent->LabelRemoteNetwork->hide();
 		newprofilewizardnetworkcontent->RemoteNetMaskComboBox->hide();
@@ -1134,7 +1220,8 @@ void NewProfileWizard::next ()
 				GlobalConfig->appendLogEntry( i18n( "Special server certificate can't be empty!" ) ,GlobalConfig->error);
 			}
 		}
-		if ( newprofilewizardcertcontent->x509certURLRequester->url().isEmpty())
+
+		if (!profileData->getUseOnlyCaCertAndUserAuth() && newprofilewizardcertcontent->x509certURLRequester->url().isEmpty())
 		{
 			ok=false;
 			msg+="- "+i18n("Certificate")+"\n";
@@ -1146,13 +1233,13 @@ void NewProfileWizard::next ()
 			msg+="- "+i18n("CA certificate")+"\n";
 			GlobalConfig->appendLogEntry( i18n( "CA Certificate can't be empty!" ) ,GlobalConfig->error);
 		}
-		if ( newprofilewizardcertcontent->privkeypathURLRequester->url().isEmpty())
+		if ( !profileData->getUseOnlyCaCertAndUserAuth() && newprofilewizardcertcontent->privkeypathURLRequester->url().isEmpty())
 		{
 			ok=false;
 			msg+="- "+i18n("Path to private key")+"\n";
 			GlobalConfig->appendLogEntry( i18n( "Path to private key can't be empty!" ) ,GlobalConfig->error);
 		}
-		if ( newprofilewizardcertcontent->PrivkeyPasswordEdit->text().isEmpty())
+		if ( !profileData->getUseOnlyCaCertAndUserAuth() &&  newprofilewizardcertcontent->PrivkeyPasswordEdit->text().isEmpty())
 		{
 			ok=false;
 			msg+="- "+i18n("Private key password")+"\n";
@@ -1184,6 +1271,7 @@ void NewProfileWizard::next ()
 		if ( !newprofilewizarduserpagecontent->PasswordEdit->text().isEmpty())
 		{
 			profileData->setUserPassword( newprofilewizarduserpagecontent->PasswordEdit->text() );
+
 		}
 		else
 		{
@@ -1496,7 +1584,7 @@ bool NewProfileWizard::getFinished()
 
 // void NewProfileDialog::reject()
 // {
-// 	
+//
 // }
 
 void NewProfileWizard::showPage( QWidget* page )
@@ -1679,7 +1767,7 @@ bool NewProfileWizard::importProfile(VpnAccountData::ConnectionType ConnType)
 		}
 		else
 		{
-			KMessageBox::information( 0, i18n( "Import of \"%1\" has been failed." ).arg( profileData->getName() ) );
+			KMessageBox::sorry( 0, i18n( "Import of \"%1\" has been failed." ).arg( profileData->getName() ) );
 			GlobalConfig->appendLogEntry ( i18n( "Import of \"%1\" (%2) has been failed." ).arg( profileData->getName() ).arg("PCF"), GlobalConfig->error );
 			success=false;
 		}
@@ -1697,7 +1785,7 @@ bool NewProfileWizard::importProfile(VpnAccountData::ConnectionType ConnType)
 		}
 		else
 		{
-			KMessageBox::information( 0, i18n( "Import of \"%1\" has been failed." ).arg( profileData->getName() ) );
+			KMessageBox::sorry( 0, i18n( "Import of \"%1\" has been failed." ).arg( profileData->getName() ) );
 			GlobalConfig->appendLogEntry ( i18n( "Import of \"%1\" (%2) has been failed." ).arg( profileData->getName() ).arg("OpenVPN"), GlobalConfig->error );
 			success=false;
 		}
@@ -1764,3 +1852,45 @@ bool NewProfileWizard::importP12Certificate()
 	}
 	return success;
 }
+
+void NewProfileWizard::authenticateWithUsernameAndPasswordToggled(bool)
+{
+	if (newprofilewizardopenvpnauthpagecontent->AuthWithUsernameAndPasswordCheckBox->isChecked())
+		newprofilewizardopenvpnauthpagecontent->UseOnlyCaCertAndUserAuthCheckBox->setEnabled(true);
+	else
+		newprofilewizardopenvpnauthpagecontent->UseOnlyCaCertAndUserAuthCheckBox->setEnabled(false);
+}
+
+void NewProfileWizard::pskInputToggled(const QString&)
+{
+	if (!newprofilewizardpskcontent->PSKLineEdit->text().isEmpty())
+		newprofilewizardpskcontent->CheckSavePsk->setChecked(true);
+	else
+		newprofilewizardpskcontent->CheckSavePsk->setChecked(false);
+}
+
+void NewProfileWizard::userpassToggled(const QString& )
+{
+	if (!newprofilewizarduserpagecontent->PasswordEdit->text().isEmpty())
+		newprofilewizarduserpagecontent->CheckUserPass->setChecked(true);
+	else
+		newprofilewizarduserpagecontent->CheckUserPass->setChecked(false);
+}
+
+void NewProfileWizard::usernameToggled(const QString&)
+{
+// 	if (newprofilewizarduserpagecontent->UsernameLineEdit->text().isEmpty())
+// 		newprofilewizarduserpagecontent->DontSaveUsernameCheckBox->setChecked(true);
+// 	else
+// 		newprofilewizarduserpagecontent->DontSaveUsernameCheckBox->setChecked(false);
+}
+
+void NewProfileWizard::useNtDomainNameToggled(bool)
+{
+	if (newprofilewizardpptppagecontent->NtDomainNameCheckbox->isChecked())
+		newprofilewizardpptppagecontent->NtDomainNameLineedit->setEnabled(true);
+	else
+		newprofilewizardpptppagecontent->NtDomainNameLineedit->setEnabled(false);
+}
+
+
