@@ -41,6 +41,7 @@
 #include "newprofilewizardracoon.h"
 #include "newprofilewizardfreeswan.h"
 #include "newprofilewizardopenvpn.h"
+#include "newprofilewizardopenvpnauth.h"
 #include "newprofilewizardopenvpnselection.h"
 #include "newprofilewizardpptp.h"
 #include "newprofilewizardauthselection.h"
@@ -94,6 +95,11 @@ public slots:
 	void useTlsAuthToggled(bool);
 	void useTlsRemoteHostToggled(bool);
 	void connectionStatusCheckToggled(bool);
+	void authenticateWithUsernameAndPasswordToggled(bool);
+	void pskInputToggled(const QString& str);
+	void userpassToggled(const QString& str);
+	void usernameToggled(const QString& str);
+	void useNtDomainNameToggled(bool);
 	//void reject();
 
 protected:
@@ -147,6 +153,7 @@ private:
 	QHBox *newprofilewizardfreeswanpage;
 	QHBox *newprofilewizardopenvpnpage;
 	QHBox *newprofilewizardopenvpnselectionpage;
+	QHBox *newprofilewizardopenvpnauthpage;
 	QHBox *newprofilewizardpptppage;
 	QHBox *newprofilewizardauthselectionpage;
 	QHBox *newprofilewizardpskpage;
@@ -165,6 +172,7 @@ private:
 	NewProfileWizardRacoon *newprofilewizardracoonpagecontent;
 	NewProfileWizardFreeswan *newprofilewizardfreeswanpagecontent;
 	NewProfileWizardOpenvpn *newprofilewizardopenvpnpagecontent;
+	NewProfileWizardOpenvpnAuth *newprofilewizardopenvpnauthpagecontent;
 	NewProfileWizardOpenvpnSelection *newprofilewizardopenvpnselectionpagecontent;
 	NewProfileWizardPptp *newprofilewizardpptppagecontent;
 	NewProfileWizardAuthSelection *newprofilewizardauthselectioncontent;
