@@ -69,6 +69,7 @@ public:
 	 * @return
 	 */
 	PreferencesDialog( QWidget *parent, QApplication *app,QTextEdit *LogOutput, KVpncConfig *GlobalConfig, bool showOnlyProfiles);
+	~PreferencesDialog();
 
 public slots:
 	void accept();
@@ -85,6 +86,18 @@ public slots:
 	void userAuthToggled(bool);
 	void useUdpToggled(bool);
 
+private slots:
+	void OpenvpnPathChanged(const QString&);
+	void FreeswanPathChanged(const QString&);
+	void PppdPathChanged(const QString&);
+	void PptpPathChanged(const QString&);
+	void RacoonPathChanged(const QString&);
+	void SetkeyPathChanged(const QString&);
+	void VpncPathChanged(const QString&);
+	
+	void lineeditTextChanged(const QString &);
+	void checkboxStateChanged(int);
+
 protected:
 	void setupGui();
 	QPtrList<VpnAccountData> *AccountList;
@@ -94,6 +107,8 @@ protected:
 	QString lastProfileName;
 	int KvpncDebugLevel;
 	bool canAccept;
+	QPixmap ok_icon;
+	QPixmap wrong_icon;
 
 public:
 	QApplication *app;
@@ -125,10 +140,27 @@ public:
 	ProfileCmdExecAfterConnectOptions *ProfileCmdExecAfterConnectOptionsWidget;
 	ProfileCmdExecAfterDisconnectOptions *ProfileCmdExecAfterDisconnectOptionsWidget;
 
+
+	QComboBox *ProfileGeneralSelector;
+	QComboBox *ProfileNetworkRouteSelector;
+	QComboBox *ProfileNetworkNatSelector;
+	QComboBox *ProfileNetworkVirtualIpSelector;
+	QComboBox *ProfileCertPskSelector;
+	QComboBox *ProfileUserSelector;
+	QComboBox *ProfileOpenvpnSelector;
+	QComboBox *ProfilePptpSelector;
+	QComboBox *ProfileRacoonSelector;
+	QComboBox *ProfileCiscoSelector;
+	QComboBox *ProfileCmdExecBeforeConnectSelector;
+	QComboBox *ProfileCmdExecBeforeDisconnectSelector;
+	QComboBox *ProfileCmdExecAfterConnectSelector;
+	QComboBox *ProfileCmdExecAfterDisconnectSelector;
+
 	bool profileAddedOrDeleted;
 	bool showOnlyProfiles;
 	QString NewProfileName;
 
+
 };
 
 #endif
