@@ -24,12 +24,25 @@
 #include <kurlrequester.h>
 #include <qlabel.h>
 #include <knuminput.h>
+#include <kpassdlg.h>
 
 ProfileOpenvpnOptions::ProfileOpenvpnOptions(QWidget *parent)
 		: ProfileOpenvpnOptionsBase(parent)
 {
 	NsCertTypeComboBox->insertItem("client");
 	NsCertTypeComboBox->insertItem("server");
+
+	if (UseTlsAuthCheckBox ->isChecked())
+	{
+		TlsAuthURLRequester->setEnabled(true);
+		UseTlsRemoteHostCheckBox->setEnabled(true);
+	}
+	else
+	{
+		TlsAuthURLRequester->setEnabled(false);
+		UseTlsRemoteHostCheckBox->setEnabled(false);
+	}
+
 }
 
 
@@ -84,6 +97,8 @@ void ProfileOpenvpnOptions::useHttpProxyToggeled(bool)
 		HttpProxyTimeoutIntSpinBox->setEnabled(true);
 		PortTextextLabel->setEnabled(true);
 		HttpProxyPortIntNumInput->setEnabled(true);
+		UseHttpProxyAuthCheckBox->setEnabled(true);
+		useHttpProxyAuthToggeled(UseHttpProxyAuthCheckBox->isChecked());
 	}
 	else
 	{
@@ -93,6 +108,13 @@ void ProfileOpenvpnOptions::useHttpProxyToggeled(bool)
 		HttpProxyTimeoutIntSpinBox->setEnabled(false);
 		PortTextextLabel->setEnabled(false);
 		HttpProxyPortIntNumInput->setEnabled(false);
+		UseHttpProxyAuthCheckBox->setEnabled(false);
+		HttpProxyAuthTextLabel->setEnabled(false);
+		HttpProxyAuthTypeComboBox->setEnabled(false);
+		HttpProxyUserTextLabel->setEnabled(false);
+		HttpProxyUserLineEdit->setEnabled(false);
+		HttpProxyPassTextLabel->setEnabled(false);
+		HttpProxyAuthPasswordEdit->setEnabled(false);
 	}
 }
 
@@ -128,6 +150,38 @@ void ProfileOpenvpnOptions::userdefiniedFragmentationSizeToggled(bool)
 		UserdefinedFragmentSizeSpinBox->setEnabled(false);
 }
 
+void ProfileOpenvpnOptions::useHttpProxyAuthToggeled(bool)
+{
+	if (UseHttpProxyAuthCheckBox->isChecked())
+	{
+		HttpProxyAuthTextLabel->setEnabled(true);
+		HttpProxyAuthTypeComboBox->setEnabled(true);
+		HttpProxyUserTextLabel->setEnabled(true);
+		HttpProxyUserLineEdit->setEnabled(true);
+		HttpProxyPassTextLabel->setEnabled(true);
+		HttpProxyAuthPasswordEdit->setEnabled(true);
+	}
+	else
+	{
+		HttpProxyAuthTextLabel->setEnabled(false);
+		HttpProxyAuthTypeComboBox->setEnabled(false);
+		HttpProxyUserTextLabel->setEnabled(false);
+		HttpProxyUserLineEdit->setEnabled(false);
+		HttpProxyPassTextLabel->setEnabled(false);
+		HttpProxyAuthPasswordEdit->setEnabled(false);
+	}
+}
+
+void ProfileOpenvpnOptions::authenticateWithUsernameAndPasswordToggled(bool)
+{
+	if (AuthWithUsernameAndPasswordCheckBox->isChecked())
+		UseOnlyCaCertAndUserAuthCheckBox->setEnabled(true);
+	else
+		UseOnlyCaCertAndUserAuthCheckBox->setEnabled(false);
+}
+
+
+
 
 
 
