@@ -43,6 +43,8 @@ public slots:
     void userdefinedRemotePortToggled(bool);
     void userdefiniedPacketSizeToggled(bool);
     void userdefiniedFragmentationSizeToggled(bool);
+    void useHttpProxyAuthToggeled(bool);
+    void authenticateWithUsernameAndPasswordToggled(bool);
 };
 
 #endif
