@@ -39,30 +39,18 @@ void ProfilePptpOptions::useDnsServerToggled(bool)
 		DnsServerLineedit->setEnabled( false );
 }
 
-
-void ProfilePptpOptions::mtuToggled(bool)
+void ProfilePptpOptions::useNtDomainNameToggled(bool)
 {
-	if (MtuCheckbox->isChecked())
-		MtuSpinbox->setEnabled(true);
+	if (NtDomainNameCheckbox->isChecked())
+		NtDomainNameLineedit->setEnabled(true);
 	else
-		MtuSpinbox->setEnabled(false);
-}
-
-void ProfilePptpOptions::keepDefaultRouteToggled(bool)
-{
-	if (KeepDefaultRouteCheckBox->isChecked())
-	{
-		ReplaceDefaultRouteCheckbox->setEnabled(false);
-		SetDefaultRouteCheckbox->setEnabled(false);
-	}
-	else
-	{
-		ReplaceDefaultRouteCheckbox->setEnabled(true);
-		SetDefaultRouteCheckbox->setEnabled(true);
-	}
-	
+		NtDomainNameLineedit->setEnabled(false);
 }
 
 
 
 
+
+
+
+
