@@ -35,8 +35,7 @@ public:
 
 public slots:
     void useDnsServerToggled(bool);
-    void mtuToggled(bool);
-    virtual void keepDefaultRouteToggled(bool);
+    void useNtDomainNameToggled(bool);
 };
 
 #endif
