@@ -24,47 +24,116 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
+#include <qstringlist.h>
+
 #include "toolinfo.moc"
 
-ToolInfo::ToolInfo(const QString &Name)
+ToolInfo::ToolInfo(bool programsInPath, const QString &Name)
 {
 	this->Name = Name;
+	this->programsInPath = programsInPath;
+	this->found = false;
 	/*
 		if (!PathToExec.isEmpty())
 			SearchPathList.append(PathToExec);*/
 	// 	if (GlobalConfig->KvpncDebugLevel > 0)
-// 	std::cout << "Checking for: " << Name.ascii() << std::endl;
+	// 	std::cout << "Checking for: " << Name.ascii() << std::endl;
 
-	SearchPathList.append("/bin");
-	SearchPathList.append("/sbin");
-	SearchPathList.append("/usr/bin");
-	SearchPathList.append("/usr/sbin");
-	SearchPathList.append("/usr/local/bin");
-	SearchPathList.append("/usr/local/sbin");
-	SearchPathList.append("/root/bin");
-	SearchPathList.append(QString (QString(getenv("$HOME"))+"/bin"));
+	// 	SearchPathList.append("/bin");
+	// 	SearchPathList.append("/sbin");
+	// 	SearchPathList.append("/usr/bin");
+	// 	SearchPathList.append("/usr/sbin");
+	// 	SearchPathList.append("/usr/local/bin");
+	// 	SearchPathList.append("/usr/local/sbin");
+	// 	SearchPathList.append("/root/bin");
+	// 	SearchPathList.append(QString (QString(getenv("$HOME"))+"/bin"));
 
 	Version=i18n("No info");
 
 	collectRunning=false;
 	collectOpenvpnCapabilitiesRunning=false;
+	collectToolInfo();
 }
 
 bool ToolInfo::collectToolInfo()
 {
 	bool success=false;
-	PathToExec=KStandardDirs::findExe(Name);
+
+	QStringList::Iterator it = SearchPathList.begin();
+	QString TryPath_first = *it;
+// 	std::cout << i18n("Trying first %1 at: %2").arg(Name).arg(TryPath_first) << std::endl;
+	if (!TryPath_first.isEmpty()  && QFile (TryPath_first).exists() && QFileInfo(TryPath_first).isFile() )
+		{
+// 			std::cout << i18n("%1 found at: %2").arg(Name).arg(TryPath_first) << std::endl;
+			found=true;
+			PathToExec=TryPath_first;
+	}
+	else
+	{
+		for (QStringList::Iterator it = SearchPathList.begin();it != SearchPathList.end();it++)
+		{
+			QString TryPath=QString(*it)+"/"+Name;
+// 			std::cout << i18n("Trying %1 at: %2").arg(Name).arg(TryPath) << std::endl;
+	
+			if (!TryPath.isEmpty()  && QFile (TryPath).exists() && QFileInfo(TryPath).isFile() )
+			{
+// 				std::cout << i18n("%1 found at: %2").arg(Name).arg(TryPath) << std::endl;
+				found=true;
+				PathToExec=TryPath;
+				break;
+			}
+		}
+	}
+
 
 	if (PathToExec.isEmpty())
-		PathToExec=KStandardDirs::findExe(Name, QString(QString(getenv("$HOME"))+"/bin"));
+	{
+		if (programsInPath)
+		{
+			// 			std::cerr << i18n("%1 not found in PATH").arg(Name) << std::endl;
+			PathToExec=KStandardDirs::findExe(Name);
 
-	if (PathToExec.isEmpty())
-		PathToExec=KStandardDirs::findExe(Name, QString("/sbin"));
+			if (PathToExec.isEmpty() )
+				PathToExec=KStandardDirs::findExe(Name, QString(QString(getenv("$HOME"))+"/bin"));
+			else return false;
 
-	if (PathToExec.isEmpty())
-		PathToExec=KStandardDirs::findExe(Name, QString("/usr/sbin"));
+			if (PathToExec.isEmpty())
+				PathToExec=KStandardDirs::findExe(Name, QString("/sbin"));
+			else return false;
 
-	if (!PathToExec.isEmpty())
+			if (PathToExec.isEmpty())
+				PathToExec=KStandardDirs::findExe(Name, QString("/usr/sbin"));
+			else return false;
+
+			if (PathToExec.isEmpty())
+				PathToExec=KStandardDirs::findExe(Name, QString("/usr/sbin"));
+			else return false;
+
+			if (PathToExec.isEmpty())
+				PathToExec=KStandardDirs::findExe(Name, QString("/bin"));
+			else return false;
+
+			if (PathToExec.isEmpty())
+				PathToExec=KStandardDirs::findExe(Name, QString("/usr/bin"));
+			else return false;
+
+			if (PathToExec.isEmpty())
+				PathToExec=KStandardDirs::findExe(Name, QString("/usr/local/sbin"));
+			else return false;
+
+			if (PathToExec.isEmpty())
+				PathToExec=KStandardDirs::findExe(Name, QString("/usr/local/bin"));
+			else return false;
+		}
+		else
+		{
+
+		}
+	}
+
+
+
+	if ( found==true)
 	{
 
 		CollectToolInfoProcess = new QProcess(this);
@@ -100,8 +169,8 @@ bool ToolInfo::collectToolInfo()
 			CollectToolInfoProcess->addArgument("-V");
 		else	if (Name == "kill")
 		{
-// 			run=false;
-// 			success=true;
+			// 			run=false;
+			// 			success=true;
 			CollectToolInfoProcess->addArgument("-V");
 		}
 		else	if (Name == "killall")
@@ -116,9 +185,11 @@ bool ToolInfo::collectToolInfo()
 			CollectToolInfoProcess->addArgument("-V");
 		else	if (Name == "pptp")
 			;
+		else	if (Name == "l2tpd")
+			;
 		else
 		{
-			std::cout << "Invalid tool (" << Name.ascii() <<")!" << std::endl;
+			// 			std::cout << "Invalid tool (" << Name.ascii() <<")!" << std::endl;
 			run=false;
 			success=false;
 		}
@@ -168,16 +239,16 @@ void ToolInfo::readStdOutCollectToolInfo()
 	{
 		QString msg = QString( CollectToolInfoProcess->readLineStdout() );
 		//	QString msg = QString( CollectToolInfoProcess->readStdout() );
-// 		std::cout << "Checking for: " << Name.ascii() << std::endl;
-// 		std::cout << "stdout collectToolInfo: " << msg.ascii() <<std::endl;
+		// 		std::cout << "Checking for: " << Name.ascii() << std::endl;
+		// 		std::cout << "stdout collectToolInfo: " << msg.ascii() <<std::endl;
 
 		//FIXME how it could be better?
 		if (Name == "vpnc")
 		{
 			if ( msg.find( "version", 0, FALSE ) > -1 )
 			{
-				std::cout << "stdout collectToolInfo: " << msg << std::endl;
-				std::cout << "stdout collectToolInfo: 2,2 " << msg.simplifyWhiteSpace().section(' ',2,2)<< std::endl;
+				// 								std::cout << "stdout collectToolInfo: " << msg.ascii() << std::endl;
+				// 								std::cout << "stdout collectToolInfo: 2,2 " << msg.simplifyWhiteSpace().section(' ',2,2).ascii() << std::endl;
 				Version = msg.simplifyWhiteSpace().section(' ',2,2);
 			}
 		}
@@ -185,7 +256,7 @@ void ToolInfo::readStdOutCollectToolInfo()
 		{
 			if ( msg.find( "wan", 0, FALSE ) > -1 )
 			{
-// 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
+				// 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
 				if ( msg.find( "openswan", 0, FALSE ) > -1 )
 					Version = msg.section(' ',2,2);
 				else
@@ -281,8 +352,8 @@ void ToolInfo::readStdErrCollectToolInfo()
 	while (CollectToolInfoProcess->canReadLineStderr())
 	{
 		QString msg = QString( CollectToolInfoProcess->readLineStderr() );
-// 				std::cout << "Checking for: " << Name.ascii() << std::endl;
-// 		std::cout << "stderr collectToolInfo: " << msg.ascii() <<std::endl;
+		// 				std::cout << "Checking for: " << Name.ascii() << std::endl;
+		// 		std::cout << "stderr collectToolInfo: " << msg.ascii() <<std::endl;
 
 		if (Name == "pppd")
 		{
@@ -321,7 +392,7 @@ void ToolInfo::readStdErrCollectToolInfo()
 		{
 			if ( msg.find( "pptp version", 0, FALSE ) > -1 )
 			{
-//				std::cout << "stdout collectToolInfo: " << msg.ascii() << std::endl;
+				//				std::cout << "stdout collectToolInfo: " << msg.ascii() << std::endl;
 				Version = msg.section(' ',2,2).section(')',0,0);
 			}
 		}
@@ -334,7 +405,7 @@ void ToolInfo::readStdOutCollectOpenvpnCapabilies()
 	{
 		QString msg = QString( CollectOpenvpnCapabilitiesProcess->readLineStdout() );
 		//	QString msg = QString( CollectOpenvpnCapabilitiesProcess->readStdout() );
-// 		std::cout << "stdout collectOpenvpnCapabilities: " << msg.ascii() <<std::endl;
+		// 		std::cout << "stdout collectOpenvpnCapabilities: " << msg.ascii() <<std::endl;
 		if ( msg.find( "PKCS#11 Options:", 0, FALSE ) > -1 )
 			Capabilities+=i18n("pkcs11 support")+";";
 
@@ -347,7 +418,7 @@ void ToolInfo::readStdErrCollectOpenvpnCapabilies()
 	while (CollectOpenvpnCapabilitiesProcess->canReadLineStderr())
 	{
 		QString msg = QString( CollectOpenvpnCapabilitiesProcess->readLineStderr() );
-// 		std::cout << "stderr collectOpenvpnCapabilities: " << msg.ascii() <<std::endl;
+		// 		std::cout << "stderr collectOpenvpnCapabilities: " << msg.ascii() <<std::endl;
 
 	}
 }
@@ -358,20 +429,32 @@ void ToolInfo::processFinished()
 	collectOpenvpnCapabilitiesRunning=false;
 }
 
-void ToolInfo::addSearchPath(const QString& )
+void ToolInfo::addSearchPath(const QString& path )
 {
-	/*
-	std::cout << "Path added: " << path << std::endl;
+
+	// 	std::cout << "Path added: " << path << std::endl;
 	if (!path.isEmpty())
 		SearchPathList.insert(SearchPathList.begin(), QString(path));
 	else
-	*/
-	return;
+
+		return;
 }
 
+void ToolInfo::removeSearchPath(const QString& path )
+{
+
+	// 	std::cout << "Path removed: " << path << std::endl;
+	if (!path.isEmpty())
+		SearchPathList.remove(QString(path));
+	else
+
+		return;
+}
+
+
 void ToolInfo::getOpenvpnCapabilities()
 {
-	
+
 	if (Name=="openvpn" && !PathToExec.isEmpty())
 	{
 
@@ -385,7 +468,7 @@ void ToolInfo::getOpenvpnCapabilities()
 		CollectOpenvpnCapabilitiesProcess->addArgument(PathToExec);
 		if (Name == "vpnc")
 			CollectOpenvpnCapabilitiesProcess->addArgument("--help");
-	
+
 		collectOpenvpnCapabilitiesRunning=false;
 
 		if ( !PathToExec.isEmpty() && !CollectOpenvpnCapabilitiesProcess->start() )
