@@ -111,6 +111,13 @@ ToolsInfoDialog::ToolsInfoDialog(KVpncConfig *GlobalConfig, QWidget *parent, con
 				tool->collectToolInfo();
 			}
 		}
+		else	if (tool->Name == "l2tpd")
+		{
+			if (!GlobalConfig->pathToL2tpd.isEmpty()) {
+				tool->addSearchPath(GlobalConfig->pathToL2tpd.section('/',0,-2));
+				tool->collectToolInfo();
+			}
+		}
 		else	if (tool->Name == "iptables")
 		{
 			if (!GlobalConfig->pathToIptables.isEmpty()) {
@@ -165,9 +172,8 @@ ToolsInfoDialog::ToolsInfoDialog(KVpncConfig *GlobalConfig, QWidget *parent, con
 			//std::cout << "Invalid tool!" << std::endl;
 		}
 
-// 		std::cout << "Version: " << tool->Version.ascii() << std::endl;
 
-		if (!tool->PathToExec.isEmpty())
+		if (!tool->PathToExec.isEmpty() && QFile (tool->PathToExec).exists() && QFileInfo(tool->PathToExec).isFile() )
 		{
 			state=i18n("Found");
 			if (tool->Name == "vpnc")
@@ -284,8 +290,11 @@ ToolsInfoDialog::ToolsInfoDialog(KVpncConfig *GlobalConfig, QWidget *parent, con
 			state=i18n("Not found");
 			usability=i18n("none");
 		}
+
+// 		std::cout << "Tool: " << tool->Name.ascii() << " Path: "<< tool->PathToExec.ascii() << " Version: " << tool->Version.ascii() << " Found: " << state.ascii() << std::endl;
+
 		QListViewItem *item = new QListViewItem(main->InfoListView, tool->Name,state, tool->Version, tool->PathToExec, usability, comment);
-		if (!tool->PathToExec.isEmpty())
+		if (tool->found)
 			item->setPixmap(1,ok_icon);
 		else
 			item->setPixmap(1,wrong_icon);
