@@ -16,7 +16,7 @@
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
-***************************************************************************/ 
+***************************************************************************/
 //BEGIN INCLUDES
 #include "utils.h"
 #include <qstring.h>
@@ -195,6 +195,7 @@ QPtrList<ToolInfo>* Utils::getToolList() {
 	ToolNamesList->append( "ipsec" ); // freeswan
 	ToolNamesList->append( "pppd" );
 	ToolNamesList->append( "pptp" );
+	ToolNamesList->append( "l2tpd" );
 	ToolNamesList->append( "setkey" );
 	ToolNamesList->append( "iptables" );
 	ToolNamesList->append( "openssl" );
@@ -210,7 +211,42 @@ QPtrList<ToolInfo>* Utils::getToolList() {
 	for ( QStringList::Iterator it = ToolNamesList->begin(); it != ToolNamesList->end(); it++ ) {
 		//std::cout << "tool: " << *it << std::endl;
 
-		currentTool = new ToolInfo( *it );
+		currentTool = new ToolInfo(config->programsInPath, *it );
+		if (!config->programsInPath)
+		{
+		if (currentTool->Name == "vpnc")
+			currentTool->PathToExec = config->pathToVpnc;
+		else	if (currentTool->Name == "ipsec")
+			currentTool->PathToExec = config->pathToFreeswan;
+		else	if (currentTool->Name == "racoon")
+			currentTool->PathToExec = config->pathToRacoon;
+		else	if (currentTool->Name == "setkey")
+			currentTool->PathToExec = config->pathToSetkey;
+		else	if (currentTool->Name == "openvpn")
+			currentTool->PathToExec = config->pathToOpenvpn;
+		else	if (currentTool->Name == "openssl")
+			currentTool->PathToExec = config->pathToOpenssl;
+		else	if (currentTool->Name == "pppd")
+			currentTool->PathToExec = config->pathToPppd;
+		else	if (currentTool->Name == "iptables")
+			currentTool->PathToExec = config->pathToIptables;
+		else	if (currentTool->Name == "kill")
+			currentTool->PathToExec = config->pathToKill;
+		else	if (currentTool->Name == "killall")
+			currentTool->PathToExec = config->pathToKillall;
+		else	if (currentTool->Name == "ping")
+			currentTool->PathToExec = config->pathToPing;
+		else	if (currentTool->Name == "ip")
+			currentTool->PathToExec = config->pathToIp;
+		else	if (currentTool->Name == "ifconfig")
+			currentTool->PathToExec = config->pathToIfconfig;
+		else	if (currentTool->Name == "route")
+			currentTool->PathToExec = config->pathToRoute;
+		else	if (currentTool->Name == "pptp")
+			currentTool->PathToExec = config->pathToPptp;
+		else	if (currentTool->Name == "l2tpd")
+			currentTool->PathToExec = config->pathToL2tpd;
+		}
 		ToolList->append( currentTool );
 		//currentTool=0L;
 		// 			std::cout << "tool: " << currentTool->Name << std::endl;
