@@ -57,6 +57,9 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	PreSharedKeyFile="";
 	HashAlgo="md5";
 	Description="";
+	HttpProxyAuthType="";
+	HttpProxyUser="";
+	HttpProxyPass="";
 	saveUserPassword=false;
 	savePsk=false;
 	useAdvancedSettings=false;
@@ -88,11 +91,12 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	CommandAfterConnect="";
 	CommandBeforeDisconnect="";
 	CommandAfterDisconnect="";
-	useNoBsdComp=false;
-	useNoDeflate=false;
+	useNoBsdComp=true;
+	useNoDeflate=true;
 	setDefaultRoute=false;
 	replaceDefaultRoute=false;
 	useMtu=false;
+	useMru=false;
 	useVirtualIP=false;
 	VirtualIP="";
 	PskIsInFile=false;
@@ -140,6 +144,7 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	setDefaultRoute=false;
 	replaceDefaultRoute=false;
 	useMtu=false;
+	useMru=false;
 	useVirtualIP=false;
 	PskIsInFile=false;
 	useAdditionalNetworkRoutes=false;
@@ -164,12 +169,16 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	disableCcp=false;
 	useXauthInteractive=false;
 	savePrivateKeyPassword=false;
+	useHttpProxyAuth=false;
+	useOnlyCaCertAndUserAuth=false;
 
 	PeerTimeout=60;
 	ReconnectDelay=5;
 	connectionStatusInterval=20;
-	Mtu=1500;
+	Mtu=1492;
+	Mru=1492;
 	LocalPort=500;
+	RemotePort=500;
 	UserdefinedPort=10000;
 	UdpPort=4500;
 	HttpProxyPort=3128;
@@ -537,6 +546,16 @@ int VpnAccountData::getMtu() const
 	return Mtu;
 }
 
+bool VpnAccountData::getUseMru() const
+{
+	return useMru;
+}
+
+int VpnAccountData::getMru() const
+{
+	return Mru;
+}
+
 bool VpnAccountData::getUseVirtualIP() const
 {
 	return useVirtualIP;
@@ -772,6 +791,35 @@ bool VpnAccountData::getSavePrivateKeyPassword() const
 	return savePrivateKeyPassword;
 }
 
+bool VpnAccountData::getUseHttpProxyAuth() const
+{
+	return useHttpProxyAuth;
+}
+
+
+QString VpnAccountData::getHttpProxyAuthType() const
+{
+	return HttpProxyAuthType;
+}
+
+
+QString VpnAccountData::getHttpProxyUser() const
+{
+	return HttpProxyUser;
+}
+
+
+QString VpnAccountData::getHttpProxyPass() const
+{
+	return HttpProxyPass;
+}
+
+bool VpnAccountData::getUseOnlyCaCertAndUserAuth() const
+{
+	return useOnlyCaCertAndUserAuth;
+}
+
+
 /* set methods */
 void VpnAccountData::setConnectionType( ConnectionType type )
 {
@@ -1108,6 +1156,17 @@ void VpnAccountData::setMtu(int Mtu)
 	this->Mtu = Mtu;
 }
 
+void VpnAccountData::setUseMru(bool useMru)
+{
+	this->useMru = useMru;
+}
+
+void VpnAccountData::setMru(int Mru)
+{
+	this->Mru = Mru;
+}
+
+
 void VpnAccountData::setUseVirtualIP(bool useVirtualIP )
 {
 	this->useVirtualIP = useVirtualIP;
@@ -1357,3 +1416,28 @@ void VpnAccountData::setSavePrivateKeyPassword( bool savePrivateKeyPassword)
 {
 	this->savePrivateKeyPassword = savePrivateKeyPassword;
 }
+
+void VpnAccountData::setUseHttpProxyAuth( bool useHttpProxyAuth )
+{
+	this->useHttpProxyAuth = useHttpProxyAuth;
+}
+
+void VpnAccountData::setHttpProxyAuthType(QString HttpProxyAuthType)
+{
+	this->HttpProxyAuthType = HttpProxyAuthType;
+}
+
+void VpnAccountData::setHttpProxyUser(QString HttpProxyUser)
+{
+	this->HttpProxyUser = HttpProxyUser;
+}
+
+void VpnAccountData::setHttpProxyPass( QString HttpProxyPass )
+{
+	this->HttpProxyPass = HttpProxyPass;
+}
+
+void VpnAccountData::setUseOnlyCaCertAndUserAuth(bool useOnlyCaCertAndUserAuth)
+{
+	this->useOnlyCaCertAndUserAuth = useOnlyCaCertAndUserAuth;
+}
