@@ -35,6 +35,7 @@
 class VpnAccountData : public QObject
 {
 public:
+// 	enum ConnectionType {cisco=0, racoon=1, freeswan=2, pptp=3,openvpn=4,l2tpd_racoon=5,l2tpd_freeswan=6,other=7};
 	enum ConnectionType {cisco=0, racoon=1, freeswan=2, pptp=3,openvpn=4,other=5};
 	enum AuthenticationType {cert=0, psk=1};
 
@@ -94,10 +95,15 @@ public:
 	QString getTlsRemoteHost() const;
 	QString getRightNextHop() const;
 	QString getLeftNextHop() const;
+	QString getHttpProxyAuthType() const;
+	QString getHttpProxyUser() const;
+	QString getHttpProxyPass() const;
+
 	int getLocalPort() const; //< returns LocalPort
 	int getRemotePort() const; //< returns RemotePort
 	int getUdpPort() const; //< returns UdpPort
 	int getMtu() const;
+	int getMru() const;
 	int getUserdefinedPort() const;
 	int getConnectionStatusCheckSuccessCount() const;
 	int getConnectionStatusInterval() const;
@@ -142,6 +148,7 @@ public:
 	bool getSetDefaultRoute() const;
 	bool getReplaceDefaultRoute() const;
 	bool getUseMtu() const;
+	bool getUseMru() const;
 	bool getUseVirtualIP() const;
 	bool getPskIsInFile() const;
 	bool getUseAdditionalNetworkRoutes() const;
@@ -169,6 +176,8 @@ public:
 	bool getUseSmardcard() const;
 	bool getUseXauthInteractive() const;
 	bool getSavePrivateKeyPassword() const;
+	bool getUseHttpProxyAuth () const;
+	bool getUseOnlyCaCertAndUserAuth() const;
 
 	/**
 	 *   Sets the connection type
@@ -287,7 +296,9 @@ public:
 	void setSetDefaultRoute(bool setDefaultRoute);
 	void setReplaceDefaultRoute(bool setReplaceDefaultRoute);
 	void setUseMtu(bool useMtu);
+	void setUseMru(bool useMru);
 	void setMtu (int Mtu);
+	void setMru (int Mru);
 	void setUseVirtualIP (bool useVirtualIP);
 	void setVirtualIP( const QString &VirtualIP );
 	void setPskIsInFile(bool PskIsInFile );
@@ -338,6 +349,12 @@ public:
 	void setUseSmardcard( bool useSmardcard );
 	void setUseXauthInteractive( bool useXauthInteractive );
 	void setSavePrivateKeyPassword ( bool savePrivateKeyPassword );
+	void setUseHttpProxyAuth (bool useHttpProxyAuth );
+	void setHttpProxyAuthType(QString HttpProxyAuthType );
+	void setHttpProxyUser(QString HttpProxyUser );
+	void setHttpProxyPass(QString HttpProxyPass );
+	void setUseOnlyCaCertAndUserAuth(bool useOnlyCaCertAndUserAuth );
+
 
 protected:
 	QString Name; //< Name of the profile
@@ -383,6 +400,9 @@ protected:
 	QString TlsRemoteHost;
 	QString RightNextHop; // freeswan
 	QString LeftNextHop; // freeswan
+	QString HttpProxyAuthType;
+	QString HttpProxyUser;
+	QString HttpProxyPass;
 
 	QStringList AdditionalNetworkRoutes;
 
@@ -419,6 +439,7 @@ protected:
 	bool setDefaultRoute; //< for PPTP
 	bool replaceDefaultRoute; //< for PPTP
 	bool useMtu;
+	bool useMru;
 	bool useVirtualIP; //< freeswan/racoon
 	bool PskIsInFile; //< Read PSK from file
 	bool useAdditionalNetworkRoutes;
@@ -446,7 +467,10 @@ protected:
 	bool useSmardcard;
 	bool useXauthInteractive;
 	bool savePrivateKeyPassword;
+	bool useHttpProxyAuth;
+	bool useOnlyCaCertAndUserAuth; //< use only a CA certificate and authentication with username and password (openvpn)
 	int Mtu;
+	int Mru;
 	int UdpPort; //< Port number of UDP port
 	int LocalPort; //< userdefined local port
 	int RemotePort; //< userdefined remote port
